pub fn body_limit_layer(bytes: usize) -> RequestBodyLimitLayerExpand description
Build a layer that rejects request bodies larger than bytes.
pub fn body_limit_layer(bytes: usize) -> RequestBodyLimitLayerBuild a layer that rejects request bodies larger than bytes.